Sphinx-Icon
===========

.. image:: https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat
    :alt: All contributors
    :target: AUTHORS.rst

.. image:: https://img.shields.io/badge/License-BSD_2--Clause-orange.svg
    :target: LICENSE
    :alt: License: BSD 2-Clause

.. image:: https://badge.fury.io/py/sphinx-icon.svg
    :target: https://badge.fury.io/py/sphinx-icon
    :alt: PyPI version
    
.. image:: https://img.shields.io/pypi/dm/sphinx-icon?color=307CC2&logo=python&logoColor=gainsboro  
    :target: https://pypi.org/project/sphinx-icon/
    :alt: PyPI - Downloads
    
.. image:: https://img.shields.io/pypi/pyversions/sphinx-icon
   :target: https://pypi.org/project/sphinx-icon/
   :alt: supported Python version

.. image:: https://github.com/12rambau/sphinx-icon/actions/workflows/unit.yml/badge.svg
    :target: https://github.com/12rambau/sphinx-icon/actions/workflows/unit.yml
    :alt: build

.. image:: https://codecov.io/gh/12rambau/sphinx-icon/branch/main/graph/badge.svg?token=NSdnY0hJpF
    :target: https://codecov.io/gh/12rambau/sphinx-icon
    :alt: Test Coverage
    
.. image:: https://readthedocs.org/projects/sphinx-icon/badge/?version=latest
    :target: https://sphinx-icon.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
    
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black badge
   
.. image:: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg
   :target: https://conventionalcommits.org
   :alt: conventional commit

Overview
--------

:code:`sphinx-icon` is a Sphinx extention to allow developers to use the :code:`icon` role to display inlined icons. 
The extention currently supports only Fontawsome 5.15.4 icons.
Please go to our `doc <https://sphinx-icon.readthedocs.io/en/latest/>`__ if you want to know more.

Contribute
----------

If you want to contribute you can fork the project in you own repository and then use it. 
If you consider working with us, please follow the `contributing guidelines <https://github.com/12rambau/sphinx-icon/blob/main/CONTRIBUTING.rst>`__. 
Meet our `contributor <https://github.com/12rambau/sphinx-icon/blob/main/AUTHORS.rst>`__. 
